package com.madplanet.cq.workflow.tutorial.basic.services.osgi.servlet;

import org.apache.felix.scr.annotations.Component;
import org.apache.felix.scr.annotations.Properties;
import org.apache.felix.scr.annotations.Property;
import org.apache.felix.scr.annotations.Service;
import org.apache.sling.api.SlingHttpServletRequest;
import org.apache.sling.api.SlingHttpServletResponse;
import org.apache.sling.api.servlets.SlingSafeMethodsServlet;
import org.apache.sling.commons.json.JSONException;
import org.apache.sling.commons.json.io.JSONWriter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import java.io.IOException;

@Component( immediate = true, metatype = true )
@Service
@Properties(
    {
        @Property(
            name = "sling.servlet.paths",
            value = {
                "/bin/tutorial/workflow/test/selection"
            },
            propertyPrivate = true
        ),
        @Property(
            name = "sling.servlet.methods",
            value = { "GET", "POST" },
            propertyPrivate = true
        ),
        @Property(
            name = "service.description",
            value = "Provides Test Selection Data",
            propertyPrivate = true
        )
    }
)
public class TestSelectionDataProviderServlet
    extends SlingSafeMethodsServlet
{

    private static final Logger LOGGER = LoggerFactory.getLogger( TestSelectionDataProviderServlet.class );

    @Override
    protected void doGet( SlingHttpServletRequest pSlingHttpServletRequest, SlingHttpServletResponse pSlingHttpServletResponse )
        throws ServletException, IOException
    {

        LOGGER.debug( "Got request on path: '{}'", pSlingHttpServletRequest.getPathInfo() );

        pSlingHttpServletResponse.setContentType( "application/json" );
        pSlingHttpServletResponse.setCharacterEncoding( "utf-8" );

        JSONWriter lJSONWriter = new JSONWriter( pSlingHttpServletResponse.getWriter() );

        try {
            lJSONWriter.array();
            writeLine( lJSONWriter, "First Selection", "First Value", "First Tip" );
            writeLine( lJSONWriter, "Second Selection", "Second Value", "Second Tip" );
            writeLine( lJSONWriter, "Third Selection", "Third Value", "Third Tip" );
            lJSONWriter.endArray();
        } catch( JSONException e ) {
            LOGGER.warn( "Failed to write JSon Response", e );
        }

        pSlingHttpServletResponse.getWriter().flush();
    }

    private void writeLine( JSONWriter pWriter, String pText, String pValue, String pTip )
        throws JSONException
    {
        pWriter.object();
        pWriter.key( "text").value( pText );
        pWriter.key( "value" ).value( pValue );
        pWriter.key( "qtip" ).value( pTip );
        pWriter.endObject();
    }
}